@@ -13,7 +13,7 @@ def get_brightness(
     display: Optional[Union[int, str]] = None,
     method: Optional[str] = None,
     verbose_error: bool = False
-) -> Union[List[int], int]:
+) -> List[int]:
     '''
     Returns the current display brightness
 
@@ -25,8 +25,8 @@ def get_brightness(
         verbose_error (bool): controls the level of detail in the error messages
 
     Returns:
-        int: an integer from 0 to 100 if only one display is detected
-        list: if there a multiple displays connected it may return a list of integers (invalid monitors return `None`)
+        list: a list of integers (from 0 to 100), each integer being the
+            percentage brightness of a display (invalid displays may return None)
 
     Example:
         ```python
@@ -52,7 +52,7 @@ def set_brightness(
     force: bool = False,
     verbose_error: bool = False,
     no_return: bool = True
-) -> Union[None, List[int], int]:
+) -> Union[None, List[int]]:
     '''
     Sets the screen brightness
 
@@ -71,8 +71,8 @@ def set_brightness(
 
     Returns:
         None: if the `no_return` kwarg is `True`
-        list: list of ints (0 to 100) only if the `no_return` kwarg is `False`
-        int: if only one display is affected and the `no_return` kwarg is `False`
+        list: a list of integers (from 0 to 100), each integer being the
+            percentage brightness of a display (invalid displays may return None)
 
     Example:
         ```python
@@ -103,17 +103,16 @@ def set_brightness(
                 identifier = Monitor.get_identifier(monitor)[1]
                 output.append(
                     set_brightness(
-                        get_brightness(display=identifier) + value,
+                        get_brightness(display=identifier)[0] + value,
                         display=identifier,
                         force=force,
                         verbose_error=verbose_error,
                         no_return=no_return
                     )
                 )
-            output = flatten_list(output)
-            return output[0] if len(output) == 1 else output
+            return flatten_list(output)
 
-        value += get_brightness(display=Monitor.get_identifier(monitors[0])[1])
+        value += get_brightness(display=Monitor.get_identifier(monitors[0])[1])[0]
     else:
         value = int(float(str(value)))
 
@@ -137,7 +136,7 @@ def fade_brightness(
     increment: int = 1,
     blocking: bool = True,
     **kwargs
-) -> Union[List[threading.Thread], List[int], int]:
+) -> Union[List[threading.Thread], List[int]]:
     '''
     A function to somewhat gently fade the screen brightness from `start` to `finish`
 
@@ -189,10 +188,6 @@ def fade_brightness(
     def err_msg(e):
         return f'\n\tfilter_monitors -> {type(e).__name__}: {e}'
 
-    threads = []
-    if 'verbose_error' in kwargs:
-        del kwargs['verbose_error']
-
     try:
         # make sure only compatible kwargs are passed to filter_monitors
         available_monitors = filter_monitors(
@@ -200,27 +195,30 @@ def fade_brightness(
                 'display', 'haystack', 'method', 'include'
             )}
         )
-    except (IndexError, LookupError) as e:
-        if isinstance(e, LookupError) and platform.system() == 'Linux' and method is None:
+    except (LookupError, ValueError) as e:
+        if not platform.system() == 'Linux':
+            raise ScreenBrightnessError(err_msg(e)) from e
+
+        method = kwargs.get('method', None)
+        if isinstance(e, LookupError) and method is None:
             # if a user ONLY has XBacklight installed and no method was specified
-            # then filter_monitors will raise a LookupError
-            available_monitors = [method.XBacklight]
-        else:
-            raise ScreenBrightnessError(err_msg(e)) from e
-    except ValueError as e:
-        if platform.system() == 'Linux' and (str(kwargs.get('method', '')).lower() == 'xbacklight'):
-            available_monitors = [method.XBacklight]
+            # then filter_monitors will raise a LookupError. In this case, default to using
+            # linux.XBacklight method
+            available_monitors = [_OS_MODULE.XBacklight]
+        elif isinstance(e, ValueError) and method.lower() == 'xbacklight':
+            # low level `list_monitors_info` will raise a ValueError if 'xbacklight' is passed as the method
+            # because xbacklight cannot query individual monitor information
+            available_monitors = [_OS_MODULE.XBacklight]
         else:
             raise ScreenBrightnessError(err_msg(e)) from e
+
     except Exception as e:
         raise ScreenBrightnessError(err_msg(e)) from e
 
+    threads = []
     for i in available_monitors:
         try:
-            if (
-                platform.system() == 'Linux'
-                and str(kwargs.get('method', '')).lower() == 'xbacklight'
-            ):
+            if platform.system() == 'Linux' and i == _OS_MODULE.XBacklight:
                 monitor = i
             else:
                 monitor = Monitor(i)
@@ -294,7 +292,7 @@ def list_monitors_info(method: Optional[str] = None, allow_duplicates: bool = Fa
     '''
     info = __cache__.get('monitors_info', method=method, allow_duplicates=allow_duplicates)
     if info is None:
-        info = globals()['method'].list_monitors_info(method=method, allow_duplicates=allow_duplicates)
+        info = _OS_MODULE.list_monitors_info(method=method, allow_duplicates=allow_duplicates)
         __cache__.store('monitors_info', info, method=method, allow_duplicates=allow_duplicates)
     return info
 
@@ -942,8 +940,8 @@ def __brightness(
         if platform.system() == 'Linux' and display is None and method in ('xbacklight', None):
             try:
                 if meta_method == 'set':
-                    linux.XBacklight.set_brightness(*args)
-                output.append(linux.XBacklight.get_brightness())
+                    _OS_MODULE.XBacklight.set_brightness(*args)
+                output.append(_OS_MODULE.XBacklight.get_brightness())
             except Exception as e:
                 format_exc('XBacklight', e)
         else:
@@ -978,9 +976,7 @@ def __brightness(
                 and ((no_return and output_is_none) or not output_is_none)
             )
         ):
-            if no_return:
-                return None
-            return output[0] if len(output) == 1 else output
+            return None if no_return else output
 
     # if the function hasn't returned then it has failed
     msg = '\n'
@@ -1034,15 +1030,14 @@ class __Cache(dict):
 
 
 __cache__ = __Cache()
-plat = platform.system()
-if plat == 'Windows':
+
+if platform.system() == 'Windows':
     from . import windows
-    method = windows
-elif plat == 'Linux':
+    _OS_MODULE = windows
+elif platform.system() == 'Linux':
     from . import linux
-    method = linux
-elif plat == 'Darwin':
+    _OS_MODULE = linux
+elif platform.system() == 'Darwin':
     raise NotImplementedError('MAC is not yet supported')
 else:
-    raise NotImplementedError(f'{plat} is not yet supported')
-del plat
+    raise NotImplementedError(f'{platform.system()} is not yet supported')
