@@ -340,6 +340,9 @@ class XBacklight:
             int: from 0 to 100
             **kwargs: arbitrary keyword arguments. Ignored
 
+        Raises:
+            ValueError: if xbacklight does not produce any valid output
+
         Example:
             ```python
             import screen_brightness_control as sbc
@@ -348,6 +351,8 @@ class XBacklight:
             ```
         '''
         result = subprocess.check_output([cls.executable, '-get']).decode()
+        if not result:
+            raise ValueError('no valid output was received from xbacklight')
         return int(round(float(str(result)), 0))
 
 
